@@ -15,16 +15,16 @@ object AuxiliaryGibbsSampler {
       priorModel.logFullConditional(i, subset, p) + samplingModel.logDensity(i, subset)
     }
     for (i <- 0 until nItems) {
-      val (tmpPartition, formerSubsetForI) = p.removeWithSubset(i)
+      val (tmpPartition, formerSubsetForI) = p.removeWithCluster(i)
       p = tmpPartition
-      val emptySubset = if (formerSubsetForI.nItems > 0) Subset.empty(samplingModel)
+      val emptySubset = if (formerSubsetForI.size > 0) Subset.empty(samplingModel.sample())
       else formerSubsetForI
       val elements = p.map(subset => (subset, logPosterior(i, subset)))
       val elementForEmpty = (emptySubset, logPosterior(i, emptySubset))
       val distribution = Distribution(p, i, Some(elementForEmpty) ++ elements, true, true)
       p = distribution.sample(rdg)
     }
-    p = p.replaceParameters(samplingModel.sample)
+    p = p.replace(samplingModel.sample)
     (p, true)
   }
 
